Frontal ablation
================

OGGM has a simple parameterisation for frontal ablation that can be used
during the ice volume estimation and for dynamical runs. These features
are still in the testing phase and are switched off per default.

Visit our `tutorials <https://tutorials.oggm.org>`_
if you are interested and would like to give them a go.

.. figure:: https://oggm.org/img/blog/calving_param/calving_ex.png
    :width: 100%
    :align: left

    Illustration of the water-depth – calving-rate feedbacks. See the tutorials
    for more details.
